import type { FormEvent, FormHTMLAttributes, ReactNode } from 'react';
import type { FieldValues, FormStore, MaybePromise, ResponseData } from '../types';
/**
 * Value type of the submit event object.
 */
export type SubmitEvent = Event & {
    submitter: HTMLElement;
} & {
    currentTarget: HTMLFormElement;
    target: Element;
};
/**
 * Function type to handle the submission of the form.
 */
export type SubmitHandler<TFieldValues extends FieldValues> = (values: TFieldValues, event: FormEvent<HTMLFormElement>) => MaybePromise<any>;
/**
 * Value type of the form properties.
 */
export type FormProps<TFieldValues extends FieldValues, TResponseData extends ResponseData> = Omit<FormHTMLAttributes<HTMLFormElement>, 'onSubmit'> & {
    of: FormStore<TFieldValues, TResponseData>;
    onSubmit: SubmitHandler<TFieldValues>;
    keepResponse?: boolean;
    shouldActive?: boolean;
    shouldTouched?: boolean;
    shouldDirty?: boolean;
    shouldFocus?: boolean;
    children: ReactNode;
};
/**
 * HTML form element that simplifies form submission and disables the browser's
 * default form validation.
 */
export declare function Form<TFieldValues extends FieldValues, TResponseData extends ResponseData>({ of: form, onSubmit, keepResponse, shouldActive, shouldTouched, shouldDirty, shouldFocus, ...props }: FormProps<TFieldValues, TResponseData>): JSX.Element;
